package org.dromara.payment.coverpage.mapper;

import org.apache.ibatis.annotations.Param;
import org.dromara.payment.coverpage.domain.CoverPageBo;
import org.dromara.payment.coverpage.domain.CoverPageInfo;
import org.dromara.payment.coverpage.domain.MerBillInfo;

import java.util.List;

/**
 * @Title CoverPageMapper
 * @Description
 * @Author wuchuang
 * @Date 2024/5/31 10:35
 */
public interface CoverPageMapper {

    CoverPageInfo selectMerCountInfo(@Param("merId") Long merId, @Param("sydId") Long sydId);

    CoverPageInfo selectOpCountInfo(@Param("opId") Long busId);

    CoverPageInfo selectChannelCountInfo(@Param("channelId") Long busId,@Param("channelNo")String busNo);

    CoverPageInfo selectSydCountInfo(@Param("sydId")  Long busId);

    List<MerBillInfo> selectMerTransactionListById(CoverPageBo bo);

    List<MerBillInfo> select30DaysById(CoverPageBo bo);


    CoverPageInfo  selectAllCountInfo();
}
